@@ -10,7 +10,7 @@
     :license: BSD, see LICENSE for more details.
 """
 
-__version__ = '0.8.1'
+__version__ = '0.10.1'
 
 # utilities we import from Werkzeug and Jinja2 that are unused
 # in the module but are exported as public interface.
@@ -20,22 +20,31 @@ from jinja2 import Markup, escape
 
 from .app import Flask, Request, Response
 from .config import Config
-from .helpers import url_for, jsonify, json_available, flash, \
-    send_file, send_from_directory, get_flashed_messages, \
-    get_template_attribute, make_response, safe_join
-from .globals import current_app, g, request, session, _request_ctx_stack
-from .ctx import has_request_context
+from .helpers import url_for, flash, send_file, send_from_directory, \
+    get_flashed_messages, get_template_attribute, make_response, safe_join, \
+    stream_with_context
+from .globals import current_app, g, request, session, _request_ctx_stack, \
+     _app_ctx_stack
+from .ctx import has_request_context, has_app_context, \
+     after_this_request, copy_current_request_context
 from .module import Module
 from .blueprints import Blueprint
 from .templating import render_template, render_template_string
 
 # the signals
 from .signals import signals_available, template_rendered, request_started, \
-     request_finished, got_request_exception, request_tearing_down
+     request_finished, got_request_exception, request_tearing_down, \
+     appcontext_tearing_down, appcontext_pushed, \
+     appcontext_popped, message_flashed
 
-# only import json if it's available
-if json_available:
-    from .helpers import json
+# We're not exposing the actual json module but a convenient wrapper around
+# it.
+from . import json
+
+# This was the only thing that flask used to export at one point and it had
+# a more generic name.
+jsonify = json.jsonify
 
 # backwards compat, goes away in 1.0
 from .sessions import SecureCookieSession as Session
+json_available = True
